@@ -83,11 +83,11 @@ class EaxTests(unittest.TestCase):
         ct = cipher.encrypt(self.data_128)
 
         cipher = AES.new(self.key_128, AES.MODE_EAX, nonce=self.nonce_96)
-        self.assertEqual(ct, cipher.encrypt(self.data_128))
+        self.assertEquals(ct, cipher.encrypt(self.data_128))
 
     def test_nonce_must_be_bytes(self):
         self.assertRaises(TypeError, AES.new, self.key_128, AES.MODE_EAX,
-                          nonce='test12345678')
+                          nonce=u'test12345678')
 
     def test_nonce_length(self):
         # nonce can be of any length (but not empty)
@@ -144,10 +144,10 @@ class EaxTests(unittest.TestCase):
 
     def test_data_must_be_bytes(self):
         cipher = AES.new(self.key_128, AES.MODE_EAX, nonce=self.nonce_96)
-        self.assertRaises(TypeError, cipher.encrypt, 'test1234567890-*')
+        self.assertRaises(TypeError, cipher.encrypt, u'test1234567890-*')
 
         cipher = AES.new(self.key_128, AES.MODE_EAX, nonce=self.nonce_96)
-        self.assertRaises(TypeError, cipher.decrypt, 'test1234567890-*')
+        self.assertRaises(TypeError, cipher.decrypt, u'test1234567890-*')
 
     def test_mac_len(self):
         # Invalid MAC length
@@ -226,7 +226,7 @@ class EaxTests(unittest.TestCase):
             for chunk in break_up(plaintext, chunk_length):
                 ct2 += cipher.encrypt(chunk)
             self.assertEqual(ciphertext, ct2)
-            self.assertEqual(cipher.digest(), ref_mac)
+            self.assertEquals(cipher.digest(), ref_mac)
 
     def test_bytearray(self):
 
